
.. py:currentmodule:: pythreejs

Controls
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: Controls()
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.ThreeWidget`.

    Three.js docs: https://threejs.org/docs/#api/controls/Controls


    .. py:attribute:: controlling

        .. sourcecode:: python

            Instance(Object3D, allow_none=False).tag(sync=True, **widget_serialization)

